@@ -23,6 +23,9 @@ import (
 	"strings"
 	"time"
 
+	"github.com/apache/answer/internal/base/reason"
+	"github.com/segmentfault/pacman/errors"
+
 	"github.com/apache/answer/internal/base/validator"
 	"github.com/apache/answer/internal/entity"
 	"github.com/apache/answer/pkg/converter"
@@ -97,6 +100,12 @@ func (req *QuestionAdd) Check() (errFields []*validator.FormErrorField, err erro
 			tag.ParsedText = converter.Markdown2HTML(tag.OriginalText)
 		}
 	}
+	if req.HTML == "" {
+		return append(errFields, &validator.FormErrorField{
+			ErrorField: "content",
+			ErrorMsg:   reason.QuestionContentCannotEmpty,
+		}), errors.BadRequest(reason.QuestionContentCannotEmpty)
+	}
 	return nil, nil
 }
 
@@ -129,6 +138,21 @@ func (req *QuestionAddByAnswer) Check() (errFields []*validator.FormErrorField,
 			tag.ParsedText = converter.Markdown2HTML(tag.OriginalText)
 		}
 	}
+	if req.HTML == "" {
+		errFields = append(errFields, &validator.FormErrorField{
+			ErrorField: "content",
+			ErrorMsg:   reason.QuestionContentCannotEmpty,
+		})
+	}
+	if req.AnswerHTML == "" {
+		errFields = append(errFields, &validator.FormErrorField{
+			ErrorField: "answer_content",
+			ErrorMsg:   reason.AnswerContentCannotEmpty,
+		})
+	}
+	if req.HTML == "" || req.AnswerHTML == "" {
+		return errFields, errors.BadRequest(reason.QuestionContentCannotEmpty)
+	}
 	return nil, nil
 }
 
@@ -203,6 +227,12 @@ type QuestionUpdateInviteUser struct {
 
 func (req *QuestionUpdate) Check() (errFields []*validator.FormErrorField, err error) {
 	req.HTML = converter.Markdown2HTML(req.Content)
+	if req.HTML == "" {
+		return append(errFields, &validator.FormErrorField{
+			ErrorField: "content",
+			ErrorMsg:   reason.QuestionContentCannotEmpty,
+		}), errors.BadRequest(reason.QuestionContentCannotEmpty)
+	}
 	return nil, nil
 }
 
@@ -347,6 +377,7 @@ const (
 	QuestionOrderCondScore      = "score"
 	QuestionOrderCondUnanswered = "unanswered"
 	QuestionOrderCondRecommend  = "recommend"
+	QuestionOrderCondFrequent   = "frequent"
 
 	// HotInDays limit max days of the hottest question
 	HotInDays = 90
@@ -410,6 +441,7 @@ type QuestionPageRespOperator struct {
 	Rank        int    `json:"rank"`
 	DisplayName string `json:"display_name"`
 	Status      string `json:"status"`
+	Avatar      string `json:"avatar"`
 }
 
 type AdminQuestionPageReq struct {
