@@ -291,18 +291,24 @@ func (ts *TagCommonService) ExistRecommend(ctx context.Context, tags []*schema.T
 
 func (ts *TagCommonService) HasNewTag(ctx context.Context, tags []*schema.TagItem) (bool, error) {
 	tagNames := make([]string, 0)
-	tagMap := make(map[string]struct{})
+	tagMap := make(map[string]bool)
 	for _, item := range tags {
 		item.SlugName = strings.ReplaceAll(item.SlugName, " ", "-")
 		tagNames = append(tagNames, item.SlugName)
-		tagMap[item.SlugName] = struct{}{}
+		tagMap[item.SlugName] = false
 	}
 	list, err := ts.GetTagListByNames(ctx, tagNames)
 	if err != nil {
 		return true, err
 	}
 	for _, item := range list {
-		if _, ok := tagMap[item.SlugName]; !ok {
+		_, ok := tagMap[item.SlugName]
+		if ok {
+			tagMap[item.SlugName] = true
+		}
+	}
+	for _, has := range tagMap {
+		if !has {
 			return true, nil
 		}
 	}
@@ -349,10 +355,17 @@ func (ts *TagCommonService) AddTag(ctx context.Context, req *schema.AddTagReq) (
 	}
 	tagInfoJson, _ := json.Marshal(tagInfo)
 	revisionDTO.Content = string(tagInfoJson)
-	_, err = ts.revisionService.AddRevision(ctx, revisionDTO, true)
+	revisionID, err := ts.revisionService.AddRevision(ctx, revisionDTO, true)
 	if err != nil {
 		return nil, err
 	}
+	ts.activityQueueService.Send(ctx, &schema.ActivityMsg{
+		UserID:           req.UserID,
+		ObjectID:         tagInfo.ID,
+		OriginalObjectID: tagInfo.ID,
+		ActivityTypeKey:  constant.ActTagCreated,
+		RevisionID:       revisionID,
+	})
 	return &schema.AddTagResp{SlugName: tagInfo.SlugName}, nil
 }
 
